#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2018/1/27 下午2:22
# @Author  : wudizhangzhi
from hupu.version import version

__version__ = version
__author__ = 'wudizhangzhi'
# __all__ = ['HupuApp']
